library(geomorph)
library(paleomorph)
library(EMMLi)
library(LaMBDA)
library(parallel)


## Create landmark sets and run Procrustes alignment + initial analysis of bilateral symmetry ##########
## Read in landmarks ##
setwd("X:/initial 70 landmarks")
first70.lands<-readmulti.nts(c("left803.mean.nts","rt803.mean.nts","left218.mean.nts","rt218.mean.nts",
                               "left231.mean.nts","rt231.mean.nts","left239.mean.nts","rt239.mean.nts",
                               "left443.mean.nts","rt443.mean.nts","left599.mean.nts","rt599.mean.nts",
                               "left610.mean.nts","rt610.mean.nts","left628.mean.nts","rt628.mean.nts",
                               "left657.mean.nts","rt657.mean.nts","left736.mean.nts","rt736.mean.nts",
                               "left739.mean.nts","rt739.mean.nts","left869.mean.nts","rt869.mean.nts",
                               "left884.mean.nts","rt884.mean.nts","left885.mean.nts","rt885.mean.nts",
                               "left888.mean.nts","rt888.mean.nts","left890.mean.nts","rt890.mean.nts",
                               "left891.mean.nts","rt891.mean.nts","left892.mean.nts","rt892.mean.nts",
                               "left893.mean.nts","rt893.mean.nts","left403.mean.nts","rt403.mean.nts",
                               "left406.mean.nts","rt406.mean.nts","left407.mean.nts","rt407.mean.nts",
                               "left408.mean.nts","rt408.mean.nts","left410.mean.nts","rt410.mean.nts",
                               "left411.mean.nts","rt411.mean.nts","left413.mean.nts","rt413.mean.nts"))
lasec(two.d.array(first70.lands),3,500) ## reaches 95% fit at 24 landmarks, saltations (sensu Watanabe 2018) end around 30 landmarks, fit seems to plateau near 35 landmarks


## conduct analyses with 35 landmarks
setwd("X:/Supplemental Data S2")
turkeysymm.lands<-readmulti.nts(c("left803.nts","rt803.nts","left803.2.nts","rt803.2.nts","left218.nts",
                                  "rt218.nts","left218.2.nts","rt218.2.nts","left231.nts","rt231.nts",
                                  "left231.2.nts","rt231.2.nts","left239.nts","rt239.nts","left239.2.nts",
                                  "rt239.2.nts","left443.nts","rt443.nts","left443.2.nts","rt443.2.nts",
                                  "left599.nts","rt599.nts","left599.2.nts","rt599.2.nts","left610.nts",
                                  "rt610.nts","left610.2.nts","rt610.2.nts","left628.nts","rt628.nts",
                                  "left628.2.nts","rt628.2.nts","left657.nts","rt657.nts","left657.2.nts",
                                  "rt657.2.nts","left736.nts","rt736.nts","left736.2.nts","rt736.2.nts",
                                  "left739.nts","rt739.nts","left739.2.nts","rt739.2.nts","left869.nts",
                                  "rt869.nts","left869.2.nts","rt869.2.nts","left884.nts","rt884.nts",
                                  "left884.2.nts","rt884.2.nts","left885.nts","rt885.nts","left885.2.nts",
                                  "rt885.2.nts","left888.nts","rt888.nts","left888.2.nts","rt888.2.nts",
                                  "left890.nts","rt890.nts","left890.2.nts","rt890.2.nts","left891.nts",
                                  "rt891.nts","left891.2.nts","rt891.2.nts","left892.nts","rt892.nts",
                                  "left892.2.nts","rt892.2.nts","left893.nts","rt893.nts","left893.2.nts",
                                  "rt893.2.nts","left403.nts","rt403.nts","left403.2.nts","rt403.2.nts",
                                  "left406.nts","rt406.nts","left406.2.nts","rt406.2.nts","left407.nts",
                                  "rt407.nts","left407.2.nts","rt407.2.nts","left408.nts","rt408.nts",
                                  "left408.2.nts","rt408.2.nts","left410.nts","rt410.nts","left410.2.nts",
                                  "rt410.2.nts","left411.nts","rt411.nts","left411.2.nts","rt411.2.nts",
                                  "left413.nts","rt413.nts","left413.2.nts","rt413.2.nts"))  ## two replicates per specimen
turkeysymm.gpa<-gpagen(turkeysymm.lands,surfaces=c(16:35),ProcD=F)
summary(turkeysymm.gpa)
findMeanSpec(turkeysymm.gpa$coords)  ## second replicate of OUVC 11410 left
left410<-read.ply("turkey_OUVC11410_leftear.ply")  ## load specimen for visualizations
plot(turkeysymm.gpa,mean=T,plot.param=list(mean.cex=8,mean.bg="blue",pt.cex=.2,pt.bg="red"))
## prepare geomorph dataframe
turkeysymm.ind<-as.factor(c("803","803","803","803","218","218","218","218","231","231","231","231","239","239","239","239","443","443","443","443","599","599","599","599","610","610","610","610","628","628","628","628","657","657","657","657","736","736","736","736","739","739","739","739","869","869","869","869","884","884","884","884","885","885","885","885","888","888","888","888","890","890","890","890","891","891","891","891","892","892","892","892","893","893","893","893","403","403","403","403","406","406","406","406","407","407","407","407","408","408","408","408","410","410","410","410","411","411","411","411","413","413","413","413"))
turkeysymm.side<-as.factor(c("left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right"))
turkeysymm.replicate<-as.factor(c("A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B","A","A","B","B"))
turkeysymm.brainwidth<-c(12.04,12.04,12.04,12.04,12.21,12.21,12.21,12.21,12.49,12.49,12.49,12.49,12.42,12.42,12.42,12.42,11.855,11.855,11.855,11.855,12.315,12.315,12.315,12.315,11.545,11.545,11.545,11.545,11.67,11.67,11.67,11.67,11.75,11.75,11.75,11.75,12.78,12.78,12.78,12.78,12.875,12.875,12.875,12.875,11.65,11.65,11.65,11.65,11.47,11.47,11.47,11.47,12.06,12.06,12.06,12.06,12.03,12.03,12.03,12.03,12.89,12.89,12.89,12.89,12.63,12.63,12.63,12.63,11.65,11.65,11.65,11.65,12.48,12.48,12.48,12.48,11.98,11.98,11.98,11.98,12.74,12.74,12.74,12.74,12.93,12.93,12.93,12.93,12.41,12.41,12.41,12.41,12.39,12.39,12.39,12.39,12.21,12.21,12.21,12.21,12.53,12.53,12.53,12.53)
turkeysymm.gdf<-geomorph.data.frame(turkeysymm.gpa,ind=turkeysymm.ind,side=turkeysymm.side,replicate=turkeysymm.replicate,braincaseWidth=turkeysymm.brainwidth)
## primary analysis of bilateral symmetry
turkeysymm.bilat<-bilat.symmetry(turkeysymm.gpa,ind=turkeysymm.gdf$ind,side=turkeysymm.gdf$side,replicate=turkeysymm.gdf$replicate,object.sym = F,RRPP=T,seed="random",data=turkeysymm.gdf,iter=4999)
turkeysymm.bilat
turkeysymm.pca<-plotTangentSpace(turkeysymm.gpa$coords,mesh=left410)
turkeysymm.asymm.pca<-plotTangentSpace(turkeysymm.bilat$asymm.shape,mesh=left410)
turkeysymm.symm.pca<-plotTangentSpace(turkeysymm.bilat$symm.shape,mesh=left410)
summary(turkeysymm.pca)

## Read in mean landmarks ##
meanshapes<-readmulti.nts(c("left803.mean.nts","rt803.mean.nts","left218.mean.nts","rt218.mean.nts",
                            "left231.mean.nts","rt231.mean.nts","left239.mean.nts","rt239.mean.nts",
                            "left443.mean.nts","rt443.mean.nts","left599.mean.nts","rt599.mean.nts",
                            "left610.mean.nts","rt610.mean.nts","left628.mean.nts","rt628.mean.nts",
                            "left657.mean.nts","rt657.mean.nts","left736.mean.nts","rt736.mean.nts",
                            "left739.mean.nts","rt739.mean.nts","left869.mean.nts","rt869.mean.nts",
                            "left884.mean.nts","rt884.mean.nts","left885.mean.nts","rt885.mean.nts",
                            "left888.mean.nts","rt888.mean.nts","left890.mean.nts","rt890.mean.nts",
                            "left891.mean.nts","rt891.mean.nts","left892.mean.nts","rt892.mean.nts",
                            "left893.mean.nts","rt893.mean.nts","left403.mean.nts","rt403.mean.nts",
                            "left406.mean.nts","rt406.mean.nts","left407.mean.nts","rt407.mean.nts",
                            "left408.mean.nts","rt408.mean.nts","left410.mean.nts","rt410.mean.nts",
                            "left411.mean.nts","rt411.mean.nts","left413.mean.nts","rt413.mean.nts"))  ## mean of each set of Procrustes-aligned replicates
meanshapes.gpa<-gpagen(meanshapes,surfaces=c(16:35),ProcD = F)
summary(meanshapes.gpa)
findMeanSpec(meanshapes.gpa$coords)  ## OUVC 11408 left
left408<-read.ply("turkey_OUVC11408_leftear.ply")
plot(meanshapes.gpa,mean=T,plot.param=list(mean.cex=8,mean.bg="blue",pt.cex=.2,pt.bg="red"))
## prepare geomorph dataframe
ind<-c("803","803","218","218","231","231","239","239","443","443","599","599","610","610","628","628","657","657","736","736","739","739","869","869","884","884","885","885","888","888","890","890","891","891","892","892","893","893","403","403","406","406","407","407","408","408","410","410","411","411","413","413")
side<-c("left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right","left","right")
brainwidth<-c(12.04,12.04,12.21,12.21,12.49,12.49,12.42,12.42,11.855,11.855,12.315,12.315,11.545,11.545,11.67,11.67,11.75,11.75,12.78,12.78,12.875,12.875,11.65,11.65,11.47,11.47,12.06,12.06,12.03,12.03,12.89,12.89,12.63,12.63,11.65,11.65,12.48,12.48,11.98,11.98,12.74,12.74,12.93,12.93,12.41,12.41,12.39,12.39,12.21,12.21,12.53,12.53)
meanshapes.gdf<-geomorph.data.frame(meanshapes.gpa,ind=ind,side=side,brainwidth=brainwidth)
## analysis of bilateral symmetry without multiple replicates
meanshapes.bilat<-bilat.symmetry(meanshapes.gpa,ind=meanshapes.gdf$ind,side=meanshapes.gdf$side,object.sym = F,seed = "random",RRPP = T,iter = 4999)
meanshapes.bilat
meanshapes.pca<-plotTangentSpace(meanshapes.gdf$coords,mesh=left408)  ## Principal components of overall shape variation
meanshapes.asymm.pca<-plotTangentSpace(meanshapes.bilat$asymm.shape,mesh=left408)  ## Principal components of asymmetric shape variation
meanshapes.symm.pca<-plotTangentSpace(meanshapes.bilat$symm.shape,mesh=left408)  ## Principal components of symmetric shape variation
summary(meanshapes.pca)
plotOutliers(meanshapes.gdf$coords)  ## the left labyrinth of OUVC 10891 appears to be an outlier
########################################################################################################



## create links for visualization ######################################################################
turkeysymm.links<-matrix(c(15,27,27,21,21,14,14,13,14,32,14,18,30,1,1,20,20,33,33,28,28,2,2,35,35,3,3,31,
                           31,4,4,26,26,5,5,6,6,16,16,7,7,23,23,17,17,8,9,25,25,10,10,23,23,11,11,22,22,
                           19,19,34,34,12),nrow = 31,ncol = 2,byrow = T)
turkeysymm.gridpar<-gridPar(pt.bg = "blue",pt.size = 0.5,link.col = "blue",link.lwd = 0.1,
                            tar.pt.bg = "red",tar.pt.size = 0.5,tar.link.col = "red",tar.link.lwd = 0.1)
#######################################################################################################



## Test for Allometry #################################################################################
meanshapes.allom<-procD.allometry(coords~Csize,iter=4999,seed="random",data=meanshapes.gdf)  ## test for allometry with labyrinth centroid
plotRefToTarget(mshape(meanshapes.gdf$coords),meanshapes.allom$Ahat.at.max,mesh=left408,method="surface",col="black")  ## allometry max
plotRefToTarget(mshape(turkeysymm.gdf$coords),meanshapes.allom$Ahat.at.min,mesh=left408,method="surface",col="blue")  ## allometry min

meanshapes.allom<-procD.allometry(coords~brainwidth,iter=4999,seed="random",data=meanshapes.gdf)  ## test for allometry with width of endocranium at cerebellum
plotRefToTarget(mshape(meanshapes.gdf$coords),meanshapes.allom$Ahat.at.max,mesh=left408,method="surface",col="black")  ## allometry max
plotRefToTarget(mshape(turkeysymm.gdf$coords),meanshapes.allom$Ahat.at.min,mesh=left408,method="surface",col="blue")  ## allometry min

## Additional visualization of minimal impact of allometry on shape variation
turkeysymm.allom<-lm(two.d.array(meanshapes.gdf$coords)~log(meanshapes.gdf$Csize))
turkeysymm.allomres<-resid(turkeysymm.allom)
turkeysymm.allomarray<-arrayspecs(turkeysymm.allomres+predict(lm(two.d.array(meanshapes.gdf$coords)~1)),35,3)
turkeysymm.allompca<-plotTangentSpace(turkeysymm.allomarray,mesh=left408)
scatterplot3d(turkeysymm.allompca$pc.scores[,1], turkeysymm.allompca$pc.scores[,2], 
              turkeysymm.allompca$pc.scores[,3],type="h",lty.hplot = "dashed",pch=turkeysymm.pch, 
              cex.symbols=3, color=turkeysymm.col, xlab=xlab, ylab=ylab, zlab=zlab, asp=1)
########################################################################################################



## OLS to test for additional covariates ###############################################################
turkeysymm.ols<-procD.lm(coords~Csize+braincaseWidth+replicate+Csize:braincaseWidth,data=turkeysymm.gdf,iter=4999)
par(mfrow=c(2,2))
plot(turkeysymm.ols)
summary(turkeysymm.ols)  ## replicate (i.e., measurement error) does not clearly appear to be correlated with shape

meanshapes.ols<-procD.lm(coords~Csize+brainwidth+side+Csize:brainwidth,data=meanshapes.gdf,iter=4999)
par(mfrow=c(2,2))
plot(meanshapes.ols)
summary(meanshapes.ols)  ## only an interaction between centroid size and endocranial width is found to have a clear association with shape

meanshapes.symm.ols<-procD.lm(coords~side,data=meanshapes.gdf,iter=4999)
par(mfrow=c(2,2))
plot(meanshapes.symm.ols)
summary(meanshapes.symm.ols)  ## no clear correlation is found between side and shape
########################################################################################################



## Tests of morphological disparity ####################################################################
turkeysymm.dispar<-morphol.disparity(coords~1,groups = ~ind+side,iter=9999,seed="random",data=meanshapes.gdf)
turkeysymm.dispar$Procrustes.var
turkeysymm.dispar$PV.dist
turkeysymm.dispar$PV.dist.Pval
View(turkeysymm.dispar$PV.dist.Pval<0.05)  ## very few contrasts show clear differences. Most that do cross the threshold of significance include OUVC 10891's left ear.
########################################################################################################



## Tests of integration/modularity, Global and EMMLi ###################################################
globalIntegration(meanshapes.gdf$coords,T)  ## the coordinates in this analysis appear to be moderately integrated, globally

## EMMli tests of modularity ##
turkeysymm.corr<-dotcorr(meanshapes.gdf$coords)
turkeysymm.models<-matrix(c("Rostralmost angle of rostral canal","Dorsalmost angle of rostral canal","Caudalmost angle of rostral canal","Intersection of rostral canal with common crus","Intersection of caudal canal with common crus","Dorsalmost angle of caudal canal","Lateralmost angle of caudal canal","Ventralmost angle of caudal canal","Intersection of lateral canal with vestibule","Caudalmost angle of lateral canal","Lateralmost angle of lateral canal","Pocket of ampulla of lateral canal","Center of oval window","Center of medially-located rostrocaudally-oriented crease between SCCs and cochlear duct","Ventralmost point of cochlear duct","Surface slider between 6 and 7","Surface slider dorsal to 8","Surface slider at caudodorsal angle of vestibule","Surface slider rostral to 11","Surface slider just caudodorsal to 1","Surface slider ventral to 13","Surface slider just medial to 11","Surface slider nearest junction of lateral and caudal canals","Surface slider just ventral to 6","Surface slider just rostral to 10","Surface slider nearest junction of rostral and caudal canals","Surface slider dorsal to 15","Surface slider just rostroventral to 2","Surface slider nearest junction of lateral canal with common crus","Surface slider nearest junction of rostral and lateral ampulla","Surface slider between 3 and 4","Surface slider just rostral to 14 on medial crease","Surface slider between 20 and 2","Surface slider between 19 and 12","Surface slider between 2 and 3","B","B","B","B","B","B","B","B","B","B","B","B","A","A","A","B","B","A","B","B","A","B","B","B","B","B","A","B","B","B","B","A","B","B","B","C","C","C","C","A","A","A","A","D","D","D","D","E","E","E","A","A","E","D","C","E","D","A","A","D","A","E","C","E","C","C","E","C","D","C","C","C","C","C","A","A","A","A","D","D","D","D","E","F","E","A","A","F","D","C","E","D","A","A","D","A","E","C","F","C","C","F","C","D","C"),nrow=35)
## the preceding line set up our hypotheses by identifying each landmark by name/location and then assigning each landmark to one of 2 (A, B), 4 (A, C, D, E), or 5 (A, C, D, E, F) modules, depending on the hypothesis
turkeysymm.models<-as.data.frame(turkeysymm.models)
colnames(turkeysymm.models)<-c("X","V.C","Three.canals.model","X5.modules")
EMMLi(turkeysymm.corr,26,turkeysymm.models,saveAs = "turkeysymm_models.txt")
## the model with the strongest posterior probability is a 4-module model, with similar amounts of integration within each module and, separately, similar amounts of integration between each module
turkeysymm.EMMli<-EMMLi(turkeysymm.corr,26,turkeysymm.models)
## preceding line assigned the results of the EMMLi analysis to a value that will be called later


## perform procrustes alignment separately on the EMMLi modules ##
## and test them individually with globalIntegration #############
meanshapes.R.gpa<-gpagen(meanshapes[c(1:4,20,28,30,31,33,35),,],surfaces=c(20,28,30,31,33,35),ProcD = F) ## rostral canal
globalIntegration(meanshapes.R.gpa$coords,T) ## slope = -1.5
meanshapes.C.gpa<-gpagen(meanshapes[c(5:8,16,17,23,24,26),,],surfaces=c(16,17,23,24,26),ProcD = F) ## caudal canal
globalIntegration(meanshapes.C.gpa$coords,T) ## slope = -0.97
meanshapes.L.gpa<-gpagen(meanshapes[c(9:12,19,22,25,34),,],surfaces=c(19,22,25,34),ProcD = F) ## lateral canal
globalIntegration(meanshapes.L.gpa$coords,T) ## slope = -1.02
meanshapes.CochVest.gpa<-gpagen(meanshapes[c(13:15,18,21,27,29,32),,],surfaces=c(18,21,27,29,32),ProcD = F)
globalIntegration(meanshapes.CochVest.gpa$coords,T) ## slope = -1.7
meanshapes.RosL.gpa<-gpagen(meanshapes[c(1:4,9:12,19,20,22,25,28,30,31,33:35),,],surfaces=c(19,20,22,25,28,30,31,33:35),ProcD = F)
globalIntegration(meanshapes.RosL.gpa$coords,T) ## slope = -1.03
meanshapes.RosC.gpa<-gpagen(meanshapes[c(1:8,16,17,20,23,24,26,28,30,31,33,35),,],surfaces=c(16,17,20,23,24,26,28,30,31,33,35),ProcD = F)
globalIntegration(meanshapes.RosC.gpa$coords,T) ## slope = -0.99
meanshapes.RosCV.gpa<-gpagen(meanshapes[c(1:4,13:15,18,20,21,27:33,35),,],surfaces=c(18,20,21,27:33,35),ProcD = F)
globalIntegration(meanshapes.RosCV.gpa$coords,T) ## slope = -1.06
meanshapes.CaudCV.gpa<-gpagen(meanshapes[c(5:8,13:18,21,23,24,27,29,32,34),,],surfaces=c(16:18,21,23,24,27,29,32,34),ProcD = F)
globalIntegration(meanshapes.CaudCV.gpa$coords,T) ## slope = -1.1
meanshapes.CaudL.gpa<-gpagen(meanshapes[c(5:12,16,17,19,22:26,34),,],surfaces=c(16,17,19,22:26,34),ProcD = F)
globalIntegration(meanshapes.CaudL.gpa$coords,T) ## slope = -1.18
meanshapes.LatCV.gpa<-gpagen(meanshapes[c(9:15,18,19,21,22,25,27,29,32,34),,],surfaces=c(18,19,21,22,25,27,29,32,34),ProcD = F)
globalIntegration(meanshapes.LatCV.gpa$coords,T) ## slope = -0.73
meanshapes.RCL.gpa<-gpagen(meanshapes[c(1:12,16,17,19,20,22:26,28,30,31,33:35),,],surfaces=c(16,17,19,20,22:26,28,30,31,33:35),ProcD = F)
globalIntegration(meanshapes.RCL.gpa$coords,T) ## slope = -1.2


## Break down disparity tests by module ##
meanshapes.coords<-meanshapes.gdf$coords
meanshapes.coords<-two.d.array(meanshapes.coords)
## preceding line turned coordinates into a two-dimensional array.
## Now, assign specific points to their respective module
rostralmeanshapes.coords<-meanshapes.coords[,c(1:12,58:60,82:84,88:93,97:99,103:105)]
rostralmeanshapes.coords<-arrayspecs(rostralmeanshapes.coords,10,3)
caudalmeanshapes.coords<-meanshapes.coords[,c(13:24,46:51,67:72,76:78)]
caudalmeanshapes.coords<-arrayspecs(caudalmeanshapes.coords,9,3)
lateralmeanshapes.coords<-meanshapes.coords[,c(25:36,55:57,64:66,73:75,100:102)]
lateralmeanshapes.coords<-arrayspecs(lateralmeanshapes.coords,8,3)
cochleameanshapes.coords<-meanshapes.coords[,c(37:45,52:54,61:63,79:81,85:87,94:96)]
cochleameanshapes.coords<-arrayspecs(cochleameanshapes.coords,8,3)
## Put these arrays back into the geomorph dataframe
meanshapes.gdf$rostral.coords<-rostralmeanshapes.coords
meanshapes.gdf$caudal.coords<-caudalmeanshapes.coords
meanshapes.gdf$lateral.coords<-lateralmeanshapes.coords
meanshapes.gdf$cochleavestib.coords<-cochleameanshapes.coords
## Conduct the analyses of morphological disparity on each module
cochleameanshapes.dispar<-morphol.disparity(cochleavestib.coords~1,groups=NULL,iter=9999,seed="random",data=meanshapes.gdf)
cochleameanshapes.dispar
cochleameanshapes.dispar<-morphol.disparity(cochleavestib.coords~Csize,iter=9999,seed="random",data=meanshapes.gdf)
cochleameanshapes.dispar
rostralmeanshapes.dispar<-morphol.disparity(rostral.coords~1,groups=NULL,iter=9999,seed="random",data=meanshapes.gdf)
rostralmeanshapes.dispar
rostralmeanshapes.dispar<-morphol.disparity(rostral.coords~Csize,groups=NULL,iter=9999,seed="random",data=meanshapes.gdf)
rostralmeanshapes.dispar
caudalmeanshapes.dispar<-morphol.disparity(caudal.coords~1,groups=NULL,iter=9999,seed="random",data=meanshapes.gdf)
caudalmeanshapes.dispar
caudalmeanshapes.dispar<-morphol.disparity(caudal.coords~Csize,groups=NULL,iter=9999,seed="random",data=meanshapes.gdf)
caudalmeanshapes.dispar
lateralmeanshapes.dispar<-morphol.disparity(lateral.coords~1,groups=NULL,iter=9999,seed="random",data=meanshapes.gdf)
lateralmeanshapes.dispar
lateralmeanshapes.dispar<-morphol.disparity(lateral.coords~Csize,groups=NULL,iter=9999,seed="random",data=meanshapes.gdf)
lateralmeanshapes.dispar
meanshapes.dispar<-morphol.disparity(coords~1,groups=NULL,iter=9999,seed="random",data=meanshapes.gdf)
meanshapes.dispar
meanshapes.dispar<-morphol.disparity(coords~Csize,groups=NULL,iter=9999,seed="random",data=meanshapes.gdf)
meanshapes.dispar
0.0006157056/8 ## cochlea and vestibule corrected PV
0.000590735/8 ## lateral canal corrected PV
0.0008696459/9 ## caudal canal corrected PV
0.0009187698/10 ## rostral canal corrected PV


## t-test to check for differences between variances of anatomical and sliding landmarks ##
anatomical<-c(.229,.871,.198,.003,.052,.226,.399,.447,.077,.141,.358,.069,.228,.193,2.05)
summary(anatomical)
var(anatomical)
sd(anatomical)
sliding<-c(.296,.748,.051,.055,.618,.391,.294,.284,.284,.168,.02,.054,.243,.097,.003,.166,.558,1.5,.032,.164)
summary(sliding)
var(sliding)
sd(sliding)
t.test(anatomical,sliding,"two.sided",mu=0,paired=F,var.equal = F,conf.level = .95)
## variances of the two groups aren't clearly different
#########################################################################################################


## General Script for Visualization with Overlap ########################################################
#########     Plus     ##################################################################################
## An Example Using Rights & Lefts ######################################################################
turkeysymm.leftear<-meanshapes.bilat$DA.component[,,1]
turkeysymm.leftear<-arrayspecs(turkeysymm.leftear,35,3)  ## separate out left ear
turkeysymm.rtear<-meanshapes.bilat$DA.component[,,2]
turkeysymm.rtear<-arrayspecs(turkeysymm.rtear,35,3)  ## separate out right ear
## Run the following three lines of code one after the other without opening any other rgl windows. The surfaces should plot on top of each other for comparison.
plotRefToTarget(mshape(meanshapes.gdf$coords),mshape(meanshapes.gdf$coords),mesh=left408,method="surface",col="gold") ## average shape
plotRefToTarget(mshape(meanshapes.gdf$coords),turkeysymm.leftear[,,1],mesh=left408,method="surface",col="black") ## mean left ear
plotRefToTarget(mshape(meanshapes.gdf$coords),turkeysymm.rtear[,,1],mesh=left408,method="surface",col="blue") ## mean right ear